Index: sansview/MANIFEST.IN
===================================================================
--- sansview/MANIFEST.IN	(revision 5c7cb6f96f355c83fd38853e312efba937e4c624)
+++ sansview/MANIFEST.IN	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -3,3 +3,2 @@
 include README.txt
 include license.txt
-include release_notes.txt
Index: sansview/README.txt
===================================================================
--- sansview/README.txt	(revision e4d8cdfa2b0fc2d5297fcdbdff2940211943ebea)
+++ sansview/README.txt	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -2,5 +2,5 @@
 =============
 
-SansView 2.1.1 (bug fixed)
+SasView 2.1.1 (bug fixed)
 	
 	- Added DataInfo for data in the DataExplorer and plots
@@ -47,6 +47,6 @@
 	- More functionalities on plot panels
 	- Combined Modeling and Fitting
-	- Save/open a SansView project or SansView analysis (subproject)
-	- Start the SansView application from a data file by double-clicking or from command line
+	- Save/open a SasView project or SasView analysis (subproject)
+	- Start the SasView application from a data file by double-clicking or from command line
 	- Easy manipulation of data and plot
 	- Provides Normalized residual plot
@@ -94,5 +94,5 @@
 2- Downloading and Installing
 	
-	*** Note: If you have EXE or ZIP SansView installer, you don't need any of the following.
+	*** Note: If you have EXE or ZIP SasView installer, you don't need any of the following.
 	
 	2.1- System Requirements:
@@ -101,7 +101,7 @@
 
 	2.2- Installing from source:
-		- Get the code from https://sansviewproject.svn.sourceforge.net/svnroot/sansviewproject/releases/sansview-x.x.x
-			- run 'python setup.py install' under the 'sansview-x.x.x' folder
-			- run 'python sansview.py' under the 'sansview' folder.
+		- Get the code from https://sasviewproject.svn.sourceforge.net/svnroot/sansviewproject/releases/sasview-x.x.x
+			- run 'python setup.py install' under the 'sasview-x.x.x' folder
+			- run 'python sasview.py' under the 'sasview' folder.
 		- The following modules are required (version numbers are what are used in the release build):
 			- wxPython 2.8.12.1 (NOTE: do NOT use version 2.9)
@@ -160,3 +160,3 @@
 6- Installer download website
 
-	- See: http://danse.chem.utk.edu/sansview.html
+	- See: http://danse.chem.utk.edu/sasview.html
Index: sansview/installer.iss
===================================================================
--- sansview/installer.iss	(revision 7f8cb75acf186f0d69c31b51ce7ae021c6e1752e)
+++ sansview/installer.iss	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -7,6 +7,6 @@
 
 ChangesAssociations=yes
-AppName=SansView
-AppVerName=SansView-2.1.1
+AppName=SasView
+AppVerName=SasView-2.1.1
 AppPublisher=(c) 2009 - 2012, University of Tennessee
 AppPublisherURL=http://danse.chem.utk.edu
@@ -14,9 +14,9 @@
 AppUpdatesURL=http://danse.chem.utk.edu 
 ChangesEnvironment=true 
-DefaultDirName={pf}\SansView
-DefaultGroupName=DANSE\SansView-2.1.1
+DefaultDirName={pf}\SasView
+DefaultGroupName=.\SasView-2.1.1
 DisableProgramGroupPage=yes
 LicenseFile=license.txt
-OutputBaseFilename=setupSansView
+OutputBaseFilename=setupSasView
 SetupIconFile=images\ball.ico
 Compression=lzma
@@ -27,32 +27,34 @@
 
 [Registry]
-Root: HKCR;	Subkey: ".xml\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".txt\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".asc\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".dat\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".tif\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".abs\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".d1d\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR;	Subkey: ".sans\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCR; Subkey: "applications\SansView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SansView.exe""  ""%1"""; 	 Flags: uninsdeletevalue noerror
-Root: HKCU;	Subkey: "Software\Classes\.xml\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.txt\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.asc\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.dat\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.tif\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.abs\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.d1d\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU;	Subkey: "Software\Classes\.sans\OpenWithList\SansView.exe";	 Flags: uninsdeletekey noerror
-Root: HKCU; Subkey: "Software\Classes\applications\SansView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SansView.exe""  ""%1"""; 	 Flags: uninsdeletevalue noerror
-Root: HKCR;	Subkey: ".svs";	ValueType: string;	ValueName: "";	ValueData: "{app}\SansView.exe";	 Flags: uninsdeletevalue  noerror
-Root: HKCR;	Subkey: ".fitv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SansView.exe";	 Flags: uninsdeletevalue  noerror
-Root: HKCR;	Subkey: ".inv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SansView.exe";	 Flags: uninsdeletevalue  noerror
-Root: HKCR;	Subkey: ".prv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SansView.exe";	 Flags: uninsdeletevalue  noerror
-Root: HKCR; Subkey: "{app}\SansView.exe";	ValueType: string; ValueName: "";	ValueData: "{app}\SansView File";	 Flags: uninsdeletekey  noerror 	
-Root: HKCR; Subkey: "{app}\SansView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SansView.exe""  ""%1""";	 Flags: uninsdeletevalue noerror 	
-Root: HKCR; Subkey: "{app}\images\ball.ico";	ValueType: string; ValueName: "";	ValueData: "{app}\SansView.exe,0";	 Flags: uninsdeletevalue noerror 	
-Root: HKLM; Subkey: "SYSTEM\CurrentControlSet\Control\Session Manager\Environment";	ValueType: expandsz; ValueName: "SANSVIEWPATH";	ValueData: "{app}";	 Flags: uninsdeletevalue noerror
+Root: HKCR;	Subkey: ".xml\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".txt\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".asc\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".dat\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".tif\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".abs\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".d1d\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".sans\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR;	Subkey: ".nxs\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCR; Subkey: "applications\SasView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SasView.exe""  ""%1"""; 	 Flags: uninsdeletevalue noerror
+Root: HKCU;	Subkey: "Software\Classes\.xml\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.txt\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.asc\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.dat\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.tif\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.abs\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.d1d\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.sans\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU;	Subkey: "Software\Classes\.nxs\OpenWithList\SasView.exe";	 Flags: uninsdeletekey noerror
+Root: HKCU; Subkey: "Software\Classes\applications\SasView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SasView.exe""  ""%1"""; 	 Flags: uninsdeletevalue noerror
+Root: HKCR;	Subkey: ".svs";	ValueType: string;	ValueName: "";	ValueData: "{app}\SasView.exe";	 Flags: uninsdeletevalue  noerror
+Root: HKCR;	Subkey: ".fitv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SasView.exe";	 Flags: uninsdeletevalue  noerror
+Root: HKCR;	Subkey: ".inv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SasView.exe";	 Flags: uninsdeletevalue  noerror
+Root: HKCR;	Subkey: ".prv";	ValueType: string;	ValueName: "";	ValueData: "{app}\SasView.exe";	 Flags: uninsdeletevalue  noerror
+Root: HKCR; Subkey: "{app}\SasView.exe";	ValueType: string; ValueName: "";	ValueData: "{app}\SasView File";	 Flags: uninsdeletekey  noerror 	
+Root: HKCR; Subkey: "{app}\SasView.exe\shell\open\command";	ValueType: string; ValueName: "";	ValueData: """{app}\SasView.exe""  ""%1""";	 Flags: uninsdeletevalue noerror 	
+Root: HKCR; Subkey: "{app}\images\ball.ico";	ValueType: string; ValueName: "";	ValueData: "{app}\SasView.exe,0";	 Flags: uninsdeletevalue noerror 	
+Root: HKLM; Subkey: "SYSTEM\CurrentControlSet\Control\Session Manager\Environment";	ValueType: expandsz; ValueName: "SASVIEWPATH";	ValueData: "{app}";	 Flags: uninsdeletevalue noerror
 ; Write to PATH (below) is disabled; need more tests
-;Root: HKCU; Subkey: "Environment";	ValueType: expandsz; ValueName: "PATH";	ValueData: "%SANSVIEWPATH%;{olddata}";	 Check: NeedsAddPath()
+;Root: HKCU; Subkey: "Environment";	ValueType: expandsz; ValueName: "PATH";	ValueData: "%SASVIEWPATH%;{olddata}";	 Check: NeedsAddPath()
 
 
@@ -67,19 +69,19 @@
 
 [Files]
-Source: "dist\SansView.exe";	DestDir: "{app}";	Flags: ignoreversion
+Source: "dist\SasView.exe";	DestDir: "{app}";	Flags: ignoreversion
 Source: "dist\*";	DestDir: "{app}";	Flags: ignoreversion recursesubdirs createallsubdirs
-Source: "dist\plugin_models\*";	DestDir: "{userappdata}\..\.sansview\plugin_models";	Flags: recursesubdirs createallsubdirs
-Source: "dist\config\custom_config.py";	DestDir: "{userappdata}\..\.sansview\config";	Flags: recursesubdirs createallsubdirs
+Source: "dist\plugin_models\*";	DestDir: "{userappdata}\..\.sasview\plugin_models";	Flags: recursesubdirs createallsubdirs
+Source: "dist\config\custom_config.py";	DestDir: "{userappdata}\..\.sasview\config";	Flags: recursesubdirs createallsubdirs
 ;	NOTE: Don't use "Flags: ignoreversion" on any shared system files
 
 [Icons]
-Name: "{group}\SansView";	Filename: "{app}\SansView.exe";	WorkingDir: "{app}"; IconFilename: "{app}\images\ball.ico" 
-Name: "{group}\{cm:UninstallProgram, SansView}";	 Filename: "{uninstallexe}" 
-Name: "{commondesktop}\SansView-2.1.1";	Filename: "{app}\SansView.exe";	Tasks: desktopicon; WorkingDir: "{app}" ; IconFilename: "{app}\images\ball.ico" 
-Name: "{userappdata}\Microsoft\Internet Explorer\Quick Launch\SansView-2.1.1";	Filename: "{app}\SansView.exe";	Tasks: quicklaunchicon; WorkingDir: "{app}"; IconFilename: "{app}\images\ball.ico" 
+Name: "{group}\SasView";	Filename: "{app}\SasView.exe";	WorkingDir: "{app}"; IconFilename: "{app}\images\ball.ico" 
+Name: "{group}\{cm:UninstallProgram, SasView}";	 Filename: "{uninstallexe}" 
+Name: "{commondesktop}\SasView-2.1.1";	Filename: "{app}\SasView.exe";	Tasks: desktopicon; WorkingDir: "{app}" ; IconFilename: "{app}\images\ball.ico" 
+Name: "{userappdata}\Microsoft\Internet Explorer\Quick Launch\SasView-2.1.1";	Filename: "{app}\SasView.exe";	Tasks: quicklaunchicon; WorkingDir: "{app}"; IconFilename: "{app}\images\ball.ico" 
 
 
 [Run]
-Filename: "{app}\SansView.exe";	Description: "{cm:LaunchProgram, SansView}";	Flags: nowait postinstall skipifsilent
+Filename: "{app}\SasView.exe";	Description: "{cm:LaunchProgram, SasView}";	Flags: nowait postinstall skipifsilent
 ; Install the Microsoft C++ DLL redistributable package if it is provided and the DLLs are not present on the target system.
 ; Note that the redistributable package is included if the app was built using Python 2.6 or 2.7, but not with 2.5.
@@ -111,5 +113,5 @@
   RegQueryStringValue(HKEY_CURRENT_USER,'Environment','PATH', oldpath)
   oldpath := oldpath + ';';
-  newpath := '%SANSVIEWPATH%';
+  newpath := '%SASVIEWPATH%';
   i := 0;
   while (Pos(';', oldpath) > 0) do begin
Index: sansview/installer_generator.py
===================================================================
--- sansview/installer_generator.py	(revision e3ef8dd473f130ca1f9cc7979bae2aa01d3576d5)
+++ sansview/installer_generator.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -124,5 +124,5 @@
     msg += """ValueType: %s; """ % str('string')
     msg += """ValueName: "%s";\t""" % str('') 
-    msg += """ValueData: "{app}\%s";\t""" % str("SansView File") 
+    msg += """ValueData: "{app}\%s";\t""" % str("SasView File") 
     msg += """ Flags: %s \t""" % str("uninsdeletekey  noerror")
     msg += "\n"
@@ -145,8 +145,8 @@
 
     
-    #SANSVIEWPATH
+    #SASVIEWPATH
     msg += """Root: HKLM; Subkey: "%s";\t"""  %  str('SYSTEM\CurrentControlSet\Control\Session Manager\Environment')
     msg += """ValueType: %s; """ % str('expandsz')
-    msg += """ValueName: "%s";\t""" % str('SANSVIEWPATH') 
+    msg += """ValueName: "%s";\t""" % str('SASVIEWPATH') 
     msg += """ValueData: "{app}";\t"""
     msg += """ Flags: %s""" % str('uninsdeletevalue noerror')
@@ -158,5 +158,5 @@
     msg += """ValueType: %s; """ % str('expandsz')
     msg += """ValueName: "%s";\t""" % str('PATH') 
-    msg += """ValueData: "%s;{olddata}";\t""" % str('%SANSVIEWPATH%')
+    msg += """ValueData: "%s;{olddata}";\t""" % str('%SASVIEWPATH%')
     msg += """ Check: %s""" % str('NeedsAddPath()')
     msg += "\n"
@@ -197,7 +197,7 @@
     msg += """Source: "dist\*";\tDestDir: "{app}";\t"""
     msg += """Flags: ignoreversion recursesubdirs createallsubdirs\n"""
-    msg += """Source: "dist\plugin_models\*";\tDestDir: "{userappdata}\..\.sansview\plugin_models";\t""" 
+    msg += """Source: "dist\plugin_models\*";\tDestDir: "{userappdata}\..\.sasview\plugin_models";\t""" 
     msg += """Flags: recursesubdirs createallsubdirs\n"""
-    msg += """Source: "dist\config\custom_config.py";\tDestDir: "{userappdata}\..\.sansview\config";\t""" 
+    msg += """Source: "dist\config\custom_config.py";\tDestDir: "{userappdata}\..\.sasview\config";\t""" 
     msg += """Flags: recursesubdirs createallsubdirs\n"""
     msg += """;\tNOTE: Don't use "Flags: ignoreversion" on any shared system files"""
@@ -278,5 +278,5 @@
     msg += """'PATH', oldpath)\n"""
     msg += """  oldpath := oldpath + ';';\n"""
-    msg += """  newpath := '%SANSVIEWPATH%';\n"""
+    msg += """  newpath := '%SASVIEWPATH%';\n"""
     msg += """  i := 0;\n"""
     msg += """  while (Pos(';', oldpath) > 0) do begin\n"""
Index: sansview/license.txt
===================================================================
--- sansview/license.txt	(revision c5d2760b55b41d6406a3d4bf03faa3114dad81e3)
+++ sansview/license.txt	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -11,5 +11,5 @@
 we ask that you acknowledge the use of the software with the following sentence:
 
-"This work benefited from the use of the SansView application, originally developed under NSF award DMR-0520547." 
+"This work benefited from the use of the SasView application, originally developed under NSF award DMR-0520547." 
 
 See the DANSE project web site for license information:
Index: sansview/local_config.py
===================================================================
--- sansview/local_config.py	(revision 204548cf1910e6b595b350d89fd47c4f356819c6)
+++ sansview/local_config.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -9,5 +9,5 @@
 
 # Version of the application
-__appname__ = "SansView"
+__appname__ = "SasView"
 __version__ = sans.sansview.__version__
 __build__ = sans.sansview.__build__
@@ -59,5 +59,5 @@
 
 #edit the list of file state your plugin can read
-APPLICATION_WLIST = 'SansView files (*.svs)|*.svs'
+APPLICATION_WLIST = 'SasView files (*.svs)|*.svs'
 APPLICATION_STATE_EXTENSION = '.svs'
 GUIFRAME_WIDTH = 1150
@@ -90,6 +90,6 @@
 SetupIconFile_win = os.path.join(icon_path, "ball.ico")
 SetupIconFile_mac = os.path.join(icon_path, "ball.icns")
-DefaultGroupName = "DANSE"
-OutputBaseFilename = "setupSansView"
+DefaultGroupName = "."
+OutputBaseFilename = "setupSasView"
 
 FIXED_PANEL = True
Index: sansview/setup_mac.py
===================================================================
--- sansview/setup_mac.py	(revision 270cc72e24d8ce004c1620e3b219d246dd753e19)
+++ sansview/setup_mac.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -96,5 +96,5 @@
 plist = dict(CFBundleDocumentTypes=[dict(CFBundleTypeExtensions=EXTENSIONS_LIST,
                                          CFBundleTypeIconFile=ICON,
-                                   CFBundleTypeName="sansview file",
+                                   CFBundleTypeName="sasview file",
                                    CFBundleTypeRole="Shell" )],)
 
Index: sansview/welcome_panel.py
===================================================================
--- sansview/welcome_panel.py	(revision 4851fe9e0f2563df16edc0d1a536b3cb06def360)
+++ sansview/welcome_panel.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -36,5 +36,5 @@
         wx.aui.AuiNotebook.__init__(self, parent, *args, **kwds)
         PanelBase.__init__(self)
-        #For sansview the parent is guiframe
+        #For sasview the parent is guiframe
         self.parent = parent
        
Index: setup.py
===================================================================
--- setup.py	(revision 5a313a368d195f0c86384f28cdd94225cf31b619)
+++ setup.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -1,4 +1,4 @@
 """
-    Setup for SansView
+    Setup for SasView
     #TODO: Add checks to see that all the dependencies are on the system
 """
@@ -19,5 +19,5 @@
                                  "core","include")
     except:
-        msg = "\nNumpy is needed to build SansView. "
+        msg = "\nNumpy is needed to build SasView. "
         print msg, "Try easy_install numpy.\n  %s" % str(sys.exc_value)
         sys.exit(0)
@@ -43,7 +43,7 @@
                      'sum_Ap1_1_Ap2.pyc', 'sum_p1_p2.pyc', 
                      'testmodel_2.pyc', 'testmodel.pyc', 'plugins.log']
-sans_dir = os.path.join(os.path.expanduser("~"),'.sansview')
+sans_dir = os.path.join(os.path.expanduser("~"),'.sasview')
 if os.path.isdir(sans_dir):
-    f_path = os.path.join(sans_dir, "sansview.log")
+    f_path = os.path.join(sans_dir, "sasview.log")
     if os.path.isfile(f_path):
         os.remove(f_path)
@@ -323,5 +323,5 @@
                     ] )
         
-# SansView
+# SasView
 package_dir["sans.sansview"] = "sansview"
 package_data['sans.sansview'] = ['images/*', 'media/*', 'test/*']
@@ -341,14 +341,14 @@
 
    
- # Set up SansView    
+ # Set up SasView    
 setup(
-    name="sansview",
+    name="sasview",
     version = VERSION,
-    description = "SansView application",
+    description = "SasView application",
     author = "University of Tennessee",
     author_email = "sansdanse@gmail.com",
     url = "http://danse.chem.utk.edu",
     license = "PSF",
-    keywords = "small-angle neutron scattering analysis",
+    keywords = "small-angle x-ray and neutron scattering analysis",
     download_url = "https://sourceforge.net/projects/sansviewproject/files/",
     package_dir = package_dir,

Index: sansguiframe/src/sans/guiframe/gui_manager.py
===================================================================
--- sansguiframe/src/sans/guiframe/gui_manager.py	(revision 96277b98a67c1ad7917d8d092a9e147b31b140aa)
+++ sansguiframe/src/sans/guiframe/gui_manager.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -60,12 +60,12 @@
         return os.path.abspath(os.getcwd())
     
     # Finally, try the directory of the sansview module
     #TODO: gui_manager will have to know about sansview until we
     # clean all these module variables and put them into a config class
     # that can be passed by sansview.py.
     logging.info(sys.executable)
     logging.info(str(sys.argv))
-    from sans import sansview
-    app_path = os.path.dirname(sansview.__file__)
+    from sans import sansview as sasview
+    app_path = os.path.dirname(sasview.__file__)
     logging.info("Using application path: %s", app_path)
     return app_path
@@ -75,5 +75,5 @@
         Returns the user's home directory
     """
-    userdir = os.path.join(os.path.expanduser("~"),".sansview")
+    userdir = os.path.join(os.path.expanduser("~"),".sasview")
     if not os.path.isdir(userdir):
         os.makedirs(userdir)
@@ -2104,5 +2104,5 @@
     def _on_save_project(self, event):
         """
         save the state of the SansView as *.svs
         """
         if self._current_perspective is  None:
@@ -2112,5 +2112,5 @@
         extension = '*' + APPLICATION_STATE_EXTENSION
         dlg = wx.FileDialog(self, "Save Project file",
-                            self._default_save_location, "sansview_proj",
+                            self._default_save_location, "sasview_proj",
                              extension, 
                              wx.SAVE)
@@ -2843,5 +2843,5 @@
                 self._data_panel.set_active_perspective(name)
                 self._check_applications_menu()
             #Set the SansView title
             self._set_title_name(name)
           
@@ -2849,5 +2849,5 @@
     def _set_title_name(self, name):
         """
         Set the SansView title w/ the current application name
         
         : param name: application name [string]
@@ -60,12 +60,12 @@
         return os.path.abspath(os.getcwd())
     
-    # Finally, try the directory of the sansview module
-    #TODO: gui_manager will have to know about sansview until we
+    # Finally, try the directory of the sasview module
+    #TODO: gui_manager will have to know about sasview until we
     # clean all these module variables and put them into a config class
@@ -60,12 +60,12 @@
     # clean all these module variables and put them into a config class
-    # that can be passed by sansview.py.
+    # that can be passed by sasview.py.
     logging.info(sys.executable)
     logging.info(str(sys.argv))
@@ -2104,5 +2104,5 @@
     def _on_save_project(self, event):
         """
-        save the state of the SansView as *.svs
+        save the state of the SasView as *.svs
         """
         if self._current_perspective is  None:
@@ -2843,5 +2843,5 @@
                 self._data_panel.set_active_perspective(name)
                 self._check_applications_menu()
-            #Set the SansView title
+            #Set the SasView title
             self._set_title_name(name)
           
@@ -2849,5 +2849,5 @@
     def _set_title_name(self, name):
         """
-        Set the SansView title w/ the current application name
+        Set the SasView title w/ the current application name
         
         : param name: application name [string]
Index: sansview/sansview.py
===================================================================
--- sansview/sansview.py	(revision 19e614a88b2cede7e0b229c9b1a8813b1d5a6490)
+++ sansview/sansview.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -13,10 +13,10 @@
 logging.basicConfig(level=logging.INFO,
                     format='%(asctime)s %(levelname)s %(message)s',
-                    filename=os.path.join(os.path.expanduser("~"),'sansview.log'))
+                    filename=os.path.join(os.path.expanduser("~"),'sasview.log'))
 
 import wx
 import sys
 # The below will make sure that sansview application uses the matplotlib font 
 # bundled with sansview. 
 if hasattr(sys, 'frozen'):
     mplconfigdir = os.path.join(os.path.expanduser("~"), '.matplotlib')
@@ -33,17 +33,17 @@
 import local_config
 PLUGIN_MODEL_DIR = 'plugin_models'
-
+APP_NAME = 'SasView'
 def run():
     sys.path.append(os.path.join("..","..",".."))
     from multiprocessing import freeze_support
     freeze_support()
-    sansview = SansView()
+    sasview = SasView()
         
-class SansViewApp(gui_manager.ViewApp):
+class SasViewApp(gui_manager.ViewApp):
     """
     """
   
 
-class SansView():
+class SasView():
     """
     """
@@ -52,5 +52,5 @@
         """
         #from gui_manager import ViewApp
-        self.gui = SansViewApp(0) 
+        self.gui = SasViewApp(0) 
         # Set the application manager for the GUI
         self.gui.set_manager(self)
@@ -68,5 +68,5 @@
             self.gui.add_perspective(fitting_plug)
         except:
-            logging.error("SansView: could not find Fitting plug-in module")
+            logging.error("%s: could not find Fitting plug-in module")% APP_NAME 
             logging.error(sys.exc_value)  
             
@@ -77,5 +77,5 @@
             self.gui.add_perspective(pr_plug)
         except:
-            logging.error("SansView: could not find P(r) plug-in module") 
+            logging.error("%s: could not find P(r) plug-in module")% APP_NAME
             logging.error(sys.exc_value)  
         
@@ -87,5 +87,6 @@
         except:
             raise
-            logging.error("SansView: could not find Invariant plug-in module") 
+            logging.error("%s: could not find Invariant plug-in module")% \
+                                                        APP_NAME 
             logging.error(sys.exc_value)  
         
@@ -96,5 +97,6 @@
             self.gui.add_perspective(calculator_plug)
         except:
-            logging.error("SansView: could not find Calculator plug-in module")
+            logging.error("%s: could not find Calculator plug-in module")% \
+                                                        APP_NAME
             logging.error(sys.exc_value)  
 
@@ -115,6 +117,6 @@
     from multiprocessing import freeze_support
     freeze_support()
-    #Process(target=SansView).start()
-    sansview = SansView()
+    #Process(target=SasView).start()
+    sasview = SasView()
 
    
@@ -13,10 +13,10 @@
 import wx
 import sys
-# The below will make sure that sansview application uses the matplotlib font 
-# bundled with sansview. 
+# The below will make sure that sasview application uses the matplotlib font 
+# bundled with sasview. 
 if hasattr(sys, 'frozen'):
     mplconfigdir = os.path.join(os.path.expanduser("~"), '.matplotlib')
Index: sansview/setup_exe.py
===================================================================
--- sansview/setup_exe.py	(revision 213b445604082b50b2674dbe86e6bb2af538fecc)
+++ sansview/setup_exe.py	(revision c329f4df46fa9f65cee666a22acdc32279f99e45)
@@ -19,5 +19,5 @@
 if len(sys.argv) == 1:
     sys.argv.append('py2exe')
 # When using the SansView build script, we need to be able to pass
 # an extra path to be added to the python path. The extra arguments
 # should be removed from the list so that the setup processing doesn't
@@ -31,5 +31,5 @@
         sys.argv.remove('--extrapath')
 except:
-    print "Error processing extra python path needed to build SansView\n  %s" % sys.exc_value
+    print "Error processing extra python path needed to build SasView\n  %s" % sys.exc_value
 
 from distutils.core import setup
@@ -96,5 +96,5 @@
            type="win32"
        />
-       <description>SansView</description>
+       <description>SasView</description>
        <dependency>
            <dependentAssembly>
@@ -118,8 +118,8 @@
             version="5.0.0.0"
             processorArchitecture="x86"
-            name="SansView"
+            name="SasView"
             type="win32">
           </assemblyIdentity>
-          <description>SansView</description>
+          <description>SasView</description>
           <trustInfo xmlns="urn:schemas-microsoft-com:asm.v3">
             <security>
@@ -167,5 +167,5 @@
            type="win32"
        />
-       <description>SansView</description>
+       <description>SasView</description>
        <dependency>
            <dependentAssembly>
@@ -207,5 +207,5 @@
         self.company_name = "U Tennessee"
         self.copyright = "copyright 2009 - 2012"
-        self.name = "SansView"
+        self.name = "SasView"
         
 #
@@ -317,9 +317,9 @@
 
 target_wx_client = Target(
-    description = 'SansView',
+    description = 'SasView',
     script = 'sansview.py',
     icon_resources = [(1, os.path.join(images_dir, "ball.ico"))],
     other_resources = [(24,1,manifest)],
-    dest_base = "SansView"
+    dest_base = "SasView"
     )
 
@@ -19,5 +19,5 @@
 if len(sys.argv) == 1:
     sys.argv.append('py2exe')
-# When using the SansView build script, we need to be able to pass
+# When using the SasView build script, we need to be able to pass
 # an extra path to be added to the python path. The extra arguments
 # should be removed from the list so that the setup processing doesn't